import { NextResponse } from "next/server"
import fs from "fs/promises"
import path from "path"

export async function GET(request: Request) {
  try {
    // Récupérer la liste des chapitres
    const lessonsDir = path.join(process.cwd(), "data", "lessons")
    const chapters = await fs.readdir(lessonsDir, { withFileTypes: true })

    const result: Record<string, string[]> = {}

    // Pour chaque chapitre, récupérer la liste des leçons
    for (const chapter of chapters.filter((dirent) => dirent.isDirectory())) {
      const chapterDir = path.join(lessonsDir, chapter.name)
      const lessons = await fs.readdir(chapterDir)
      result[chapter.name] = lessons
    }

    return NextResponse.json({
      success: true,
      data: result,
      cwd: process.cwd(),
      lessonsDir,
    })
  } catch (error) {
    console.error("Erreur lors de la récupération des leçons:", error)
    return NextResponse.json(
      {
        success: false,
        error: (error as Error).message,
      },
      { status: 500 },
    )
  }
}
